@@ -15,11 +15,11 @@ Artifactory::Client - Perl client for Artifactory REST API
 
 =head1 VERSION
 
-Version 0.1.0
+Version 0.1.1
 
 =cut
 
-our $VERSION = '0.1.0';
+our $VERSION = '0.1.1';
 
 =head1 SYNOPSIS
 
@@ -256,6 +256,17 @@ sub folder_info {
     return $self->get( $url );
 }
 
+=head2 file_info( $path )
+
+Returns file info
+
+=cut
+
+sub file_info {
+    my ( $self, $path ) = @_;
+    return $self->folder_info( $path ); # should be OK to do this
+}
+
 =head2 deploy_artifact( path => $path, properties => { key => [ values ] }, content => $content )
 
 Takes path, properties and content then deploys artifact.  Note that properties are a hashref with key-arrayref pairs,
